Learn R Programming

arules (version 0.2-1)

tidLists-class: Class ``tidLists'' --- A Transaction ID List

Description

The tidLists class is used by the itemsets class to store the IDs of the transaction which support each mined itemsets. Only the implementation of the Eclat mining algorithm produces transaction IDs. tidLists uses the itemMatrix class to efficiently store the transaction ID lists as a sparse matrix.

Arguments

Objects from the Class

Objects are created by Eclat if the eclat function is called with tidLists = TRUE in the ECparameter object. Objects can also be created by calls of the form new("tidLists", ...).

See Also

eclat, itemsets-class

Examples

Run this code
## Create transaction data set.
data <- list(
  c("a","b","c"),
  c("a","b"),
  c("a","b","d"),
  c("b","e"),
  c("b","c","e"),
  c("a","d","e"),
  c("a","c"),
  c("a","b","d"),
  c("c","e"),
  c("a","b","d","e"),
  )
t <- as(data, "transactions")

## Mine itemsets with tidLists.
f <- eclat(data, parameter = list(support = 0, tidLists = TRUE))

## Get dimensions of the tidLists.
dim(tidLists(f))

## Coerce tidLists to list.
as(tidLists(f), "list")

Run the code above in your browser using DataLab