Learn R Programming

arules (version 0.2-1)

image: Visual Inspection of an Object Based on ``itemMatrix''

Description

Provides the generic function image and the S4 methods to generate level plots to visually inspect objects based on itemMatrix (e.g., transactions, items in itemsets or rhs/lhs in rules). These plots can be used to identify problems in a data set (e.g., recording problems with some transactions containing all items).

Usage

image(x, ...)
## S3 method for class 'itemMatrix':
image(x, ...)
## S3 method for class 'transactions':
image(x, ...)

Arguments

x
the object.
...
further arguments passed on.

See Also

itemMatrix-class, transactions-class

Examples

Run this code
data("Epub")

# in this data set we can see that not all
# items were available from the beginning.

image(Epub)

Run the code above in your browser using DataLab